# Copyright 2013 Donald Stufft
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import absolute_import, division, print_function
from __future__ import unicode_literals

from werkzeug.routing import Rule, EndpointPrefix

urls = [
    EndpointPrefix("warehouse.packaging.views.", [
        Rule(
            "/project/<project_name>/",
            methods=["GET"],
            endpoint="project_detail",
        ),
        Rule(
            "/project/<project_name>/<version>/",
            methods=["GET"],
            endpoint="project_detail",
        ),
    ]),
]
